@@ -1,7 +1,7 @@
 '''
 Created by auto_sdk on 2018.08.13
 '''
-from libs.customize.top.api.base import RestApi
+from seven_top.top.api.base import RestApi
 class TmcTopicGroupAddRequest(RestApi):
 	def __init__(self,domain='gw.api.taobao.com',port=80):
 		RestApi.__init__(self,domain, port)
